==> haskell-aeson-better-errors-0.9.1.0-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.1.0
id: aeson-better-errors-0.9.1.0-6oS04wXkq4d23AN1VkhmqC
key: aeson-better-errors-0.9.1.0-6oS04wXkq4d23AN1VkhmqC
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
author: Harry Garrood
exposed: True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
abi: e21873fa3027c9382a9804562c0a8bf7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-better-errors-0.9.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-better-errors-0.9.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/aeson-better-errors-0.9.1.0
hs-libraries: HSaeson-better-errors-0.9.1.0-6oS04wXkq4d23AN1VkhmqC
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx base-4.9.0.0
    bytestring-0.10.8.1 dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    void-0.7.1-7ItcNGyWY8l57cMz7KooSQ
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.0-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.1.0
id: aeson-better-errors-0.9.1.0-A8HlmXSiXqB3nfafmGf5zX
key: aeson-better-errors-0.9.1.0-A8HlmXSiXqB3nfafmGf5zX
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
author: Harry Garrood
exposed: True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
abi: b2b7b33e8de1d29f7e50385a53f0011e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-better-errors-0.9.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-better-errors-0.9.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/aeson-better-errors-0.9.1.0
hs-libraries: HSaeson-better-errors-0.9.1.0-A8HlmXSiXqB3nfafmGf5zX
depends:
    aeson-1.0.2.1-9juLbWuUPUaFK1txzTGd5H base-4.9.0.0
    bytestring-0.10.8.1 dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.10-HyvEaD9RF3TGwvwmkJHXws
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    void-0.7.2-Gq1uNTFl2JaJr51CTc0tGb
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
